@@ -12,10 +12,14 @@
  *
  * ----------------------------------------------------------------------- */
 
-#include <stdlib.h>
-#include <stdarg.h>
-#include <unistd.h>
+#include <fcntl.h>
 #include <signal.h>
+#include <stdarg.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <syslog.h>
+#include <unistd.h>
 #include <sys/wait.h>
 
 #include "automount.h"
@@ -40,29 +44,60 @@ void reset_signals(void)
   sigprocmask(SIG_UNBLOCK, &allsignals, NULL);
 }
 
-int spawnv(char *prog, char **argv) {
+int spawnv(int logpri, char *prog, char **argv) {
   pid_t f;
-  int status;
+  int status, nullfd, pipefd[2];
+  FILE *errs;
+  char errbuf[1024], *p;
   sigset_t allsignals, oldsig;
   
   sigfillset(&allsignals);
   sigprocmask(SIG_BLOCK, &allsignals, &oldsig);
   
-  f = fork();
+  if ( pipe(pipefd) )
+    return -1;
+
+    f = fork();
   if ( f == 0 ) {
     reset_signals();
+    if ( (nullfd = open("/dev/null", O_RDONLY)) ) {
+      dup2(nullfd, STDIN_FILENO);
+      close(nullfd);
+    }
+    close(pipefd[0]);
+    dup2(pipefd[1], STDOUT_FILENO);
+    dup2(pipefd[1], STDERR_FILENO);
+    close(pipefd[1]);
     execv(prog, argv);
     _exit(255);	/* execv() failed */
   } else {
     sigprocmask(SIG_SETMASK, &oldsig, NULL);
-    if ( f < 0 || waitpid(f, &status, 0) != f )
+
+    close(pipefd[1]);
+
+    if ( f < 0 ) {
+      close(pipefd[0]);
+      return -1;
+    }
+
+    if ( (errs = fdopen(pipefd[0], "r")) ) {
+      while ( fgets(errbuf, 1024, errs) ) {
+	if ( (p = strchr(errbuf, '\n')) ) *p = '\0';
+	if ( errbuf[0] )	/* Don't output empty lines */
+	  syslog(logpri, ">> %s", errbuf);
+      }
+      fclose(errs);
+    } else
+      close(pipefd[0]);
+
+    if ( waitpid(f, &status, 0) != f )
       return -1; /* waitpid() failed */
     else
       return status;
   }
 }
 
-int spawnl(char *prog, ...)
+int spawnl(int logpri, char *prog, ...)
 {
   va_list arg;
   int argc;
@@ -80,6 +115,6 @@ int spawnl(char *prog, ...)
   while ((*p++ = va_arg(arg,char *)));
   va_end(arg);
   
-  return spawnv(prog, argv);
+  return spawnv(logpri, prog, argv);
 }
 
