@@ -26,8 +26,8 @@
 
 /* Standard function used by daemon or modules */
 
-int spawnl(char *, ...);
-int spawnv(char *, char **);
+int spawnl(int, char *, ...);
+int spawnv(int, char *, char **);
 void reset_signals(void);
 int do_mount(char *, char *, int, char *, char *, char *);
 
@@ -35,7 +35,7 @@ int do_mount(char *, char *, int, char *, char *, char *);
 
 /* lookup module */
 
-#define AUTOFS_LOOKUP_VERSION 3
+#define AUTOFS_LOOKUP_VERSION 4
 
 #ifdef MODULE_LOOKUP
 int lookup_init(char *, int, char **, void **);
@@ -57,7 +57,7 @@ int close_lookup(struct lookup_mod *);
 
 /* parse module */
 
-#define AUTOFS_PARSE_VERSION 2
+#define AUTOFS_PARSE_VERSION 3
 
 #ifdef MODULE_PARSE
 int parse_init(int, char **, void **);
@@ -79,7 +79,7 @@ int close_parse(struct parse_mod *);
 
 /* mount module */
 
-#define AUTOFS_MOUNT_VERSION 3
+#define AUTOFS_MOUNT_VERSION 4
 
 #ifdef MODULE_MOUNT
 int mount_init(void **);
